/* 
   TUT4.C
   Fourth example for ICC8051 4.0 tutorial
   Exercises the extended language keywords and #pragmas
   Compiler command line: (comment 1)
   ICC8051 tut4 -ml -e -L -q
   EAG 14 Jun 90 
   IMAF 23 MAR 91
*/


/* Include port definitions and interrupt declarations: (comment 2) */
#include <io51.h>

/* Include ANSI C header file for printf(): */
#include <stdio.h>


/* Allocating variables to specific memory areas: (comment 3) */

/* First by using the extended keyword form: */
void big_fast_fill(void)
  {
    xdata int xarray[100];
    data char index;
    
    for (index = 0; index <= 99; index++)
      xarray[index] = 0xFF;
  }

/* Then the same function using the ANSI #pragma form: */
void big_fast_fill2(void)
  {
#pragma memory=data
    char index;
#pragma memory=xdata
    int xarray[100];
#pragma memory=default
    for (index = 0; index <= 99; index++)
      xarray[index] = 0xFF;
  }


/* Using SFR's (Special Function Registers): (comment 4) */

/* Define an SFR register at address F8 hex in SFR space: */
sfr STATUS_REG = 0xF8;

/* Use of SFR syntax: */

void set_status_reg(void)
  {
     /* Assign a value to the whole register at once: */
     STATUS_REG = 5; 
     /* Or just one bit at a time using the "." operator: */
     STATUS_REG.3 = 0; /* now the port has bit pattern 11110111 */
     
     /* Check a bit in the SFR using only an 8051 bit instruction: */
     if (STATUS_REG.7) printf("MSB set");
     
     /* This generates a test of the whole byte: */
     if (STATUS_REG.7 & 0x80) printf("MSB set"); 
  }


/* Memory mapped I/O using constant pointers: (comment 5) */

/* Definition of an absolute constant pointer: */
#define PORT  (*(char *) 0x014000)  /* to address 4000 hex in XDATA */

/* Definition of an absolute constant pointer for subscripting: */
#define PORT_PTR ((char *) 0x014000) /* to 4000 hex in XDATA */

/* Use of constant pointers: */
char port_access(char c,int i)
   {
     PORT = c;          /* write c to absolute address */
     PORT_PTR[i] = c;   /* absolute constant pointer with index */
     return(PORT);      /* read of absolute address */
   }


/* Using bit variables: (comment 6) */

/* Define a relocatable bit variable: */
bit bit_me; /* automatically assigned a location by the linker */

/* Define an absolute bit variable: */
bit twenty_zero = 0x20.0; /* at the LSB of byte address 20 hex. */

/* Define a bit variable in a defined sfr port: */
bit STATUS_bit_3 = STATUS_REG.3;

/* Define a function with a bit argument and return value: */
bit bit_func(bit b)
  {
     unsigned int i;
     
     b ^= 1;     /* invert the bit with bitwise exclusive OR */
     i = 2 * b;  /* use math on bit like an unsigned integer */
     return (b);  
  }


/* Non-volatile memory support: (comment 7) */

/* Define a variable to reside in non-volatile RAM: */
no_init char NV_RAM_char1; /* no initial value allowed */

/* Same definition using the #pragma form: */
#pragma memory=no_init
char NV_RAM_char2;
#pragma memory=default


/* Defining ISR's (Interrupt Service Routines) from C: (comment 8) */

/* Define an ISR for External Interrupt 0, vector address 03 hex.
   The ISR will use register bank 1 instead of the default: */
interrupt [0x3] using [1] void ext_0(void)
  {
    /* service the interrupt */
  }

/* Define Timer 0 ISR based on the prototype in io51.h: */
interrupt void T0_int(void)  /* actual address specified in io51.h */
  {                            
    /* service the interrupt */
  }

/* Define Timer 1 ISR based on io51.h, using the #pragma form: */
#pragma function=interrupt
void T1_int(void)   /* actual address specified in io51.h */
  {
    /* service the interrupt */
  }
#pragma function=default


/* Define a non-interruptable function: (comment 9) */

/* Using the monitor keyword: */
monitor int non_int_func(int i)  
  {
    /* here is the uninterruptable sequence of code */
    return (i);
  }

/* Using the #pragma form: */
#pragma function=monitor
char mon_func(char a)  
  {
    /* here is the uninterruptable sequence of code */
    return (a);
  }
#pragma function=default


/* Functions prototypes using #pragmas: (comment 10) */
#pragma function=monitor
extern long mo_func( void);
#pragma function=default


#pragma memory=data
extern char a;       
#pragma memory=default         /* End of TUT4.C */
